@@ -9,6 +9,7 @@ from PyFin.API.DateUtilities import datesList
 from PyFin.API.DateUtilities import bizDatesList
 from PyFin.API.DateUtilities import holDatesList
 from PyFin.API.DateUtilities import advanceDate
+from PyFin.API.DateUtilities import isBizDay
 from PyFin.API.DateUtilities import adjustDateByCalendar
 from PyFin.API.DateUtilities import advanceDateByCalendar
 
@@ -21,6 +22,7 @@ from PyFin.API.Analysis import MAPOSITIVE
 __all__ = ["datesList",
            "bizDatesList",
            "holDatesList",
+           "isBizDay",
            "advanceDate",
            "adjustDateByCalendar",
            "advanceDateByCalendar",
